Function semantic_analysis

pub fn semantic_analysis(
    ast_root: AstRoot,
    metadata: AstMetadata,
    driver: &mut Driver,
)
Analyzes the C AST produced by the Parser for semantic errors, performs typechecking and decorates the AST with their resolved types, and then passes ownership of the AST to the IR lowering stage.